#
# spec file for package lollypop
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global gobject_introspection_version 1.35.9
%global gtk3_version 3.12

Name:           lollypop
Summary:        GNOME music playing application
License:        GPL-3.0+
Version:        0.9.205
Release:        2.2
Url:            http://gnumdk.github.io/lollypop-web/
Source0:        https://github.com/gnumdk/lollypop/releases/download/%{version}/%{name}-%{version}.tar.xz
BuildArch:      noarch
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  itstool
BuildRequires:  libxml2
BuildRequires:  python3-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= %{gobject_introspection_version}
BuildRequires:  pkgconfig(gsettings-desktop-schemas)
BuildRequires:  pkgconfig(gtk+-3.0) >= %{gtk3_version}
Requires:       gobject-introspection >= %{gobject_introspection_version}
Requires:       gstreamer
Requires:       gstreamer-plugins-base
Requires:       python3-cairo
Requires:       python3-gobject
Requires:       python3-pylast
# Can't migrate to GDBus, the server-side support is not implemented yet:
#     https://bugzilla.gnome.org/show_bug.cgi?id=656330
Requires:       dbus-1-python3
%if 0%{?suse_version} > 1320
Recommends:     python3-wikipedia
%endif
Requires(pre): desktop-file-utils
Requires(post): desktop-file-utils
Recommends:     %{name}-lang = %{version}
%glib2_gsettings_schema_requires

%description
Lollypop is a new GNOME music playing application. It provides the following
features:
* Supports mp3/4, ogg and flac
* Genre/Cover browsing
* Genre/Artist/Cover browsing
* Search
* Main playlist (called queue in other apps)
* Party mode
* Replay gain
* Cover art downloader
* Context artist view
* MTP sync
* Fullscreen view
* Radios support
* Last.fm support
* Auto install codecs
* HiDPI support
* Tunein support.

%lang_package
%prep
%setup -q

%build
# REMOVE UNNECESSARY BANG FROM NON-EXEC FILE
sed -i '1{/#!\/usr\/bin\/python/d;}' src/database_upgrade.py

%configure
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install

find %{buildroot} -name '*.la' -exec rm -f '{}' \;

%find_lang %{name} %{?no_lang_C}

# THESE CACHE FILES ARE USELESS REALLY AS THEY ARE NOT ACCOMPANIED BY CORRESPONDING SOURCE FILES
# DELETING THESE SAVES US A TON OF RPMLINT WARNINGS
rm -fr %{buildroot}%{python3_sitelib}/lollypop/__pycache__

%suse_update_desktop_file %{buildroot}/%{_datadir}/applications/%{name}.desktop

%fdupes %{buildroot}%{python3_sitelib}/%{name}/
%fdupes %{buildroot}%{_datadir}/

%post
%icon_theme_cache_post
%icon_theme_cache_post HighContrast
%desktop_database_post
%glib2_gsettings_schema_post

%postun
%icon_theme_cache_postun
%icon_theme_cache_postun HighContrast
%desktop_database_postun
%glib2_gsettings_schema_postun

%files -f %{name}.lang
%doc AUTHORS COPYING
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_datadir}/help/*/%{name}
%if 0%{?suse_version} == 1315
%dir %{_datadir}/appdata
%endif
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/glib-2.0/schemas/org.gnome.Lollypop.gschema.xml
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/icons/hicolor/*/apps/%{name}-symbolic.svg
%{python3_sitelib}/lollypop/

%changelog
* Fri Sep 23 2016 badshah400@gmail.com
- Update to version 0.9.205:
  + Youtube support.
  + MPRIS fixes.
  + Read lyrics from tags.
  + See https://github.com/gnumdk/lollypop/releases for full list
    of changes.
* Sun Sep  4 2016 mailaender@opensuse.org
- Update to version 0.9.113:
  + Enhanced search engine
  + MTP sync for albums
  + Move stats to settings dialog
  + Move artist artwork outside cache
  + Fix Lastfm scrobbler
  + Guess tracknumber from filename
  + Fix issues with Unity
  + Rework all code (may have introduced unwanted regressions)
* Fri Jul 15 2016 badshah400@gmail.com
- Update to version 0.9.112:
  + Fix an issue with image downloader:
    https://duckduckgo.com/i.js is not available anymore,
    duckduckgo API is limited to instant search... Switch to
    Google Custom Search (API key needed).
- Changes from versions 0.9.108 through 0.9.111:
  + See https://github.com/gnumdk/lollypop/releases.
* Sun Jun  5 2016 badshah400@gmail.com
- Update to version 0.9.107:
  + Bug fixes release.
- Changes from versions 0.9.106:
  + Option to store covers in tags (needs kid3).
  + Fix an issue in Fullscreen.
  + Other bug fixes.
- Changes from version 0.9.105:
  + Fix an issue with sortorder.
  + Fix an issue with HiDPI in MPRIS.
  + Fix issues with artwork cache.
  + Add support for shortcuts window.
* Sun May  8 2016 badshah400@gmail.com
- Update to version 0.9.104:
  + Fix an issue with read only fs
  + Add support for disc subtitle comment
  + Fix an issue with overlay
  + Remove arrow in list (bad with artist artwork, bad on
    elementary, ...)
- Changes from version 0.9.100 through 0.9.103:
  + See release history:
    https://github.com/gnumdk/lollypop/releases.
* Thu Apr 28 2016 badshah400@gmail.com
- Update to version 0.9.99:
  + Add support for artist artwork
  + Boost performance (one more time)
  + Bugfixes in collection scanner
  + Tunein search
- Add Recommends on python3-wikipedia for openSUSE > 1320,;
  enables the optional wikipedia feature (python3-wikipedia
  recently introduced into Factory). N.A. for openSUSE <= 13.2 or
  Leap 42.1.
* Wed Apr 27 2016 badshah400@gmail.com
- Update to version 0.9.98:
  + Last.fm was not working for users without Gnome Online
    Account.
  + Various bug fixes.
- Changes from version 0.9.97:
  + Fix an issue in MTP sync.
  + Fix an issue when showing artists for track.
- Changes from version 0.9.96:
  + Various bug fixes.
* Tue Apr 12 2016 badshah400@gmail.com
- Update to version 0.9.95:
  + Various bug fixes.
  + Enable Gnome Shell 3.20 MPRIS controls.
  + Move to GIO DBus on GNOME 3.20 (Thanks to Gnome Music code).
  + Should work again on Elementary OS.
- Delete unnecessary python cache files to avoid a ton of rpmlint
  warnings.
* Wed Apr  6 2016 badshah400@gmail.com
- Update to version 0.9.94:
  + Fix an issue with HiDPI.
* Wed Apr  6 2016 badshah400@gmail.com
- Update to version 0.9.93:
  + Fix an issue with overlays.
- Changes from version 0.9.92:
  + Allow multiple artists per album.
  + Faster album loading.
  + New Popover for context view.
  + Fixes for GNOME 3.20.
  + Remove Wikia support (broken) .
* Thu Mar 24 2016 badshah400@gmail.com
- Update to version 0.9.91:
  + Bug fixes.
- Changes from version 0.9.90:
  + Rewritten queue popover.
  + New playlists/albums popover (You can manage tracks/albums
    while browsing your collection).
  + New overlay buttons.
  + Drag & drop in playlists.
  + Fast queuing.
  + Multi playlists selection.
  + Jump to current track button.
  + Elementary OS support back.
* Wed Feb 17 2016 badshah400@gmail.com
- Update to version 0.9.86:
  + Fix an issue with crossfading.
  + Finally support artwork in notifications.
  + Add a new "responsive design" mode (Ctrl + m for Mini player).
  + Somes fixes in MTP sync.
- Changes from versions 0.9.83 through 0.9.85:
  + See upstream documentation of changes at
    https://github.com/gnumdk/lollypop/releases.
* Wed Feb  3 2016 badshah400@gmail.com
- Update to version 0.9.82:
  + Fix an important issue in collection scanner.
  + Fix an issue with progress bar.
- Changes from version 0.9.81:
  + Fix an issue in MTP code.
  + Update translations.
  + Rework settings dialog.
- Changes from version 0.9.80:
  + Crossfading support.
  + Allows user to merge views by selecting multiple items.
  + Converts files to MP3 on MTP sync (Android Phones, ...).
  + Fix an issue with headerbar.
* Thu Dec 24 2015 badshah400@gmail.com
- Update to version 0.9.75:
  + Use Duckduckgo, Google API is dead.
  +`Add a slider to select covers size.
* Sat Dec  5 2015 badshah400@gmail.com
- Update to version 0.9.74:
  + Fix issue in scanner.
- Changes from version 0.9.72:
  + Handle artist sort order tag.
  + Fix search dialog.
  + Allow popover in search dialog (Gtk 3.18).
- Changes from version 0.9.71:
  + Fix issue in fullscreen.
* Sat Nov 28 2015 badshah400@gmail.com
- Update to version 0.9.70:
  + Initial MPD support (unstable).
  + Animation when loading radios.
  + Stats in about dialog.
  + Restore window position when hidden.
  + Right click on albums.
  + Fix MTP errors.
* Fri Nov 13 2015 badshah400@gmail.com
- Initial package.
